atlinter package
================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   atlinter.metrics

Submodules
----------

.. toctree::
   :maxdepth: 4

   atlinter.data
   atlinter.optical_flow
   atlinter.pair_interpolation
   atlinter.utils

Module contents
---------------

.. automodule:: atlinter
   :members:
   :undoc-members:
   :show-inheritance:
